/**
 * Checks if the given input is a valid number and optionally, if it falls within a specific range.
 * we should also return true if the number is a valid BigInt
 * @param {string | number} input - The value to check.
 * @param {number} [minInput] - The minimum acceptable value for the input.
 * @param {number} [maxInput] - The maximum acceptable value for the input.
 * @returns {boolean} - Returns `true` if the input is a valid number and falls within the specified range. Otherwise, it returns `false`.
 */
export function ValidNumber(input, minInput, maxInput) {
    let valid = true;
    try {
        let num;
        if (typeof input === "string") {
            if (input === "")
                valid = false;
            num = Number(input);
            if (isNaN(num))
                valid = false;
        }
        else {
            num = input;
        }
        if (minInput !== undefined && num < minInput)
            valid = false;
        if (maxInput !== undefined && num > maxInput)
            valid = false;
    }
    catch (ex) {
        valid = false;
    }
    finally {
        return valid;
    }
}
